TracewayMaskBlank class

Inheritance

Constructors

TracewayMaskBlank({Color color = const Color(0xFF000000)})
const

Properties

color Color
Solid fill color. Defaults to black.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited